@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Checks for got-vs-want statements
 
@@ -31,7 +30,6 @@ representation of expression-based "got-strings".
 
 
 """
-from __future__ import print_function, division, absolute_import, unicode_literals
 import re
 import difflib
 from xdoctest import utils
@@ -148,10 +146,17 @@ def _strip_exception_details(msg):
 def extract_exc_want(want):
     """
     Args:
-        want (str):
+        want (str): the message supplied by the user
 
     Returns:
-        str:
+        str: the matchable exception part
+
+    Example:
+        extract_exc_want('''
+        Traceback (most recent call last):
+        bar
+        ''')
+
     """
     want_ = utils.codeblock(want)
     m = _EXCEPTION_RE.search(want_)
