@@ -970,6 +970,13 @@ class DocTest(object):
 
         return summary
 
+    @property
+    def globs(self):
+        """
+        Alias for ``global_namespace`` for pytest 8.0 compatability
+        """
+        return self.global_namespace
+
     @property
     def cmdline(self):
         """
